@@ -58,6 +58,12 @@ UPDATE_GENES_RESOURCES = {
     ],
     "ensembl_genes_37": ["ensembl_genes_37.txt", "ensembl_genes_37_reduced.txt"],
     "ensembl_genes_38": ["ensembl_genes_38.txt", "ensembl_genes_38_reduced.txt"],
-    "ensembl_transcripts_37": ["ensembl_transcripts_37.txt", "ensembl_transcripts_37_reduced.txt"],
-    "ensembl_transcripts_38": ["ensembl_transcripts_38.txt", "ensembl_transcripts_38_reduced.txt"],
+    "ensembl_transcripts_37": [
+        "ensembl_transcripts_37.txt",
+        "ensembl_transcripts_37_reduced.txt",
+    ],
+    "ensembl_transcripts_38": [
+        "ensembl_transcripts_38.txt",
+        "ensembl_transcripts_38_reduced.txt",
+    ],
 }
