@@ -43,5 +43,7 @@ transcript = dict(
     # If the transcript is relevant
     is_canonical=bool,
     # The MANE select transcript
-    mane_transcript=str,
+    mane_select_transcript=str,
+    # The MANE plus clinical transcript
+    mane_plus_clinical_transcript=str,
 )
