@@ -1,10 +1,15 @@
 # -*- coding: utf-8 -*-
-from flask import Blueprint, current_app, redirect, render_template, send_from_directory, url_for
+import logging
+from pathlib import Path
+
+from flask import Blueprint, current_app, render_template, send_from_directory
 from flask_ldap3_login.forms import LDAPLoginForm
 
 from scout import __version__
 from scout.server.utils import public_endpoint
 
+LOG = logging.getLogger(__name__)
+
 public_bp = Blueprint(
     "public",
     __name__,
@@ -21,7 +26,15 @@ def index():
     form = None
     if current_app.config.get("LDAP_HOST"):
         form = LDAPLoginForm()
-    return render_template("public/index.html", version=__version__, form=form)
+
+    badge_name = current_app.config.get("ACCREDITATION_BADGE")
+    if badge_name and not Path(public_bp.static_folder, badge_name).is_file():
+        LOG.warning(f'No file with name "{badge_name}" in {public_bp.static_folder}')
+        badge_name = None
+
+    return render_template(
+        "public/index.html", version=__version__, form=form, accred_badge=badge_name
+    )
 
 
 @public_bp.route("/favicon")
