@@ -10,7 +10,7 @@ LOG = logging.getLogger(__name__)
 
 
 def test_variant(real_variant_database, variant_objs, case_obj):
-    """"Test querying a variant"""
+    """Test querying a variant"""
     adapter = real_variant_database
     test_variant = list(variant_objs)[0]
 
@@ -32,7 +32,7 @@ def test_variant(real_variant_database, variant_objs, case_obj):
 
 
 def test_query_all_gene_variants(real_variant_database):
-    """"Test querying gene variants using gene symbol."""
+    """ "Test querying gene variants using gene symbol."""
     adapter = real_variant_database
 
     ## GIVEN a populated database with variants in a certain gene
