@@ -2,29 +2,41 @@
 import tempfile
 
 import pytest
+from flask import url_for
 
 from scout.server.links import get_variant_links
 from scout.server.utils import append_safe, find_index, variant_case
 
 
-def test_get_variant_links(variant_obj):
+def test_get_variant_links(app, institute_obj, variant_obj):
     """Test to get 1000g link"""
     # GIVEN a variant object without links
     assert "thousandg_link" not in variant_obj
+
     # WHEN fetching the variant links
-    links = get_variant_links(variant_obj)
-    # THEN check that links are returned
-    assert "thousandg_link" in links
+    with app.test_client() as client:
+        # GIVEN that the user could be logged in
+        resp = client.get(url_for("auto_login"))
+        assert resp.status_code == 200
+
+        links = get_variant_links(institute_obj, variant_obj)
+        # THEN check that links are returned
+        assert "thousandg_link" in links
 
 
-def test_get_str_variant_links(str_variant_obj):
+def test_get_str_variant_links(app, institute_obj, str_variant_obj):
     """Test adding links to STR variant obj, in particular check source link."""
     # GIVEN a variant object without links
     assert "str_source_link" not in str_variant_obj
     # WHEN fetching the variant links
-    links = get_variant_links(str_variant_obj)
-    # THEN check that links are returned
-    assert "str_source_link" in links
+    with app.test_client() as client:
+        # GIVEN that the user could be logged in
+        resp = client.get(url_for("auto_login"))
+        assert resp.status_code == 200
+
+        links = get_variant_links(institute_obj, str_variant_obj)
+        # THEN check that links are returned
+        assert "str_source_link" in links
 
 
 def test_find_index_bai():
